@@ -1,7 +1,5 @@
 #from out2_sup import *
 
-from datetime import datetime as datetime_
-
 import out2_sup as model_
 
 rootObj = model_.rootTag(
@@ -29,9 +27,9 @@ rootObj = model_.rootTag(
     ],
     person=[
         model_.person(
-            ratio = 3.200000,
-            id = 1,
-            value = "abcd",
+            ratio=3.200000,
+            id=1,
+            value="abcd",
             name='Alberta',
             interest=[
                 'gardening',
@@ -44,7 +42,7 @@ rootObj = model_.rootTag(
             ],
         ),
         model_.person(
-            id = 2,
+            id=2,
             name='Bernardo',
             interest=[
                 'programming',
@@ -56,9 +54,9 @@ rootObj = model_.rootTag(
                     lastname='Diddly',
                     priority=4.500000,
                     info=model_.info(
-                        rating = 5.330000,
-                        type_ = 321,
-                        name = "Albert Abasinian",
+                        rating=5.330000,
+                        type_=321,
+                        name="Albert Abasinian",
                     ),
                 ),
             ],
@@ -66,7 +64,7 @@ rootObj = model_.rootTag(
             ],
         ),
         model_.person(
-            id = 3,
+            id=3,
             name='Charlie',
             interest=[
                 'people',
@@ -100,14 +98,14 @@ rootObj = model_.rootTag(
             ],
         ),
         model_.person(
-            id = 4,
+            id=4,
         ),
     ],
     programmer=[
         model_.programmer(
-            language = "python",
-            area = "xml",
-            id = 2,
+            language="python",
+            area="xml",
+            id=2,
             name='Charles Carlson',
             interest=[
                 'programming',
@@ -119,9 +117,9 @@ rootObj = model_.rootTag(
                     lastname='Echo',
                     priority=3.800000,
                     info=model_.info(
-                        rating = 5.330000,
-                        type_ = 321,
-                        name = "George Gregory",
+                        rating=5.330000,
+                        type_=321,
+                        name="George Gregory",
                     ),
                 ),
             ],
@@ -133,29 +131,29 @@ rootObj = model_.rootTag(
             elnonposint=0,
             elnegint=-12,
             elnonnegint=4,
-            eldate=datetime_.strptime("2005-04-26", "%Y-%m-%d"),
-            eldatetime=datetime_.strptime("2005-04-26T10:11:12", "%Y-%m-%dT%H:%M:%S"),
+            eldate=model_.GeneratedsSuper.gds_parse_date("2005-04-26"),
+            eldatetime=model_.GeneratedsSuper.gds_parse_datetime("2005-04-26T10:11:12"),
             eltoken='aa bb cc dd',
             elshort=123,
             ellong=13241234123412341234,
             elparam=model_.param(
-                semantic = "a big semantic",
-                name = "Davy",
-                id = "id001",
+                semantic="a big semantic",
+                name="Davy",
+                id="id001",
                 valueOf_ = """""",
             ),
         ),
     ],
     python_programmer=[
         model_.python_programmer(
-            nick_name = "davy",
-            language = "python",
-            area = "xml",
-            vegetable = "tomato",
-            fruit = "peach",
-            ratio = 8.700000,
-            id = 232,
-            value = "abcd",
+            nick_name="davy",
+            language="python",
+            area="xml",
+            vegetable="tomato",
+            fruit="peach",
+            ratio=8.700000,
+            id=232,
+            value="abcd",
             name='Darrel Dawson',
             interest=[
                 'hang gliding',
@@ -167,9 +165,9 @@ rootObj = model_.rootTag(
                     lastname='Hippolite',
                     priority=5.200000,
                     info=model_.info(
-                        rating = 6.550000,
-                        type_ = 543,
-                        name = "Harvey Hippolite",
+                        rating=6.550000,
+                        type_=543,
+                        name="Harvey Hippolite",
                     ),
                 ),
             ],
@@ -182,14 +180,14 @@ rootObj = model_.rootTag(
     ],
     java_programmer=[
         model_.java_programmer(
-            nick_name = "davy",
-            language = "python",
-            area = "xml",
-            vegetable = "tomato",
-            fruit = "peach",
-            ratio = 8.700000,
-            id = 232,
-            value = "abcd",
+            nick_name="davy",
+            language="python",
+            area="xml",
+            vegetable="tomato",
+            fruit="peach",
+            ratio=8.700000,
+            id=232,
+            value="abcd",
             name='Darrel Dawson',
             interest=[
                 'hang gliding',
@@ -201,9 +199,9 @@ rootObj = model_.rootTag(
                     lastname='Hippolite',
                     priority=5.200000,
                     info=model_.info(
-                        rating = 6.550000,
-                        type_ = 543,
-                        name = "Harvey Hippolite",
+                        rating=6.550000,
+                        type_=543,
+                        name="Harvey Hippolite",
                     ),
                 ),
             ],
